@@ -26,6 +26,9 @@
 #include "gtkhtml-embedded.h"
 #include "htmlengine.h"
 
+/* backward-compatibility cruft */
+#include "gtk-compat.h"
+
 static void gtk_html_embedded_class_init (GtkHTMLEmbeddedClass *class);
 static void gtk_html_embedded_init       (GtkHTMLEmbedded *gspaper);
 
@@ -73,7 +76,7 @@ gtk_html_embedded_get_type (void)
 }
 
 static void
-free_param(gpointer key, gpointer value, gpointer data)
+free_param (gpointer key, gpointer value, gpointer data)
 {
 	g_free (key);
 	g_free (value);
@@ -82,12 +85,12 @@ free_param(gpointer key, gpointer value, gpointer data)
 static void
 gtk_html_embedded_finalize (GObject *object)
 {
-	GtkHTMLEmbedded *eb = GTK_HTML_EMBEDDED(object);
+	GtkHTMLEmbedded *eb = GTK_HTML_EMBEDDED (object);
 
 	g_hash_table_foreach (eb->params, free_param, NULL);
 	g_hash_table_destroy (eb->params);
-	g_free(eb->classid);
-	g_free(eb->type);
+	g_free (eb->classid);
+	g_free (eb->type);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -105,8 +108,8 @@ static void gtk_html_embedded_add (GtkContainer *container, GtkWidget *child)
 	/* can't add something twice */
 	g_return_if_fail (gtk_bin_get_child (GTK_BIN (container)) == NULL);
 
-	old_add(container, child);
-	gtk_html_embedded_changed(GTK_HTML_EMBEDDED(container));
+	old_add (container, child);
+	gtk_html_embedded_changed (GTK_HTML_EMBEDDED (container));
 }
 
 static void gtk_html_embedded_remove (GtkContainer *container, GtkWidget *child)
@@ -114,13 +117,13 @@ static void gtk_html_embedded_remove (GtkContainer *container, GtkWidget *child)
 	g_return_if_fail (container != NULL);
 	g_return_if_fail (gtk_bin_get_child (GTK_BIN (container)) != NULL);
 
-	old_remove(container, child);
+	old_remove (container, child);
 
-	gtk_html_embedded_changed(GTK_HTML_EMBEDDED(container));
+	gtk_html_embedded_changed (GTK_HTML_EMBEDDED (container));
 }
 
-typedef void (*draw_print_signal)(GtkObject *, gpointer, gpointer);
-typedef void (*draw_gdk_signal)(GtkObject *, gpointer, gpointer, gint, gint, gpointer);
+typedef void (*draw_print_signal)(GObject *, gpointer, gpointer);
+typedef void (*draw_gdk_signal)(GObject *, gpointer, gint, gint, gpointer);
 
 static void
 draw_gdk_signal_marshaller (GClosure     *closure,
@@ -150,22 +153,19 @@ draw_gdk_signal_marshaller (GClosure     *closure,
 
 	ff (data1,
 	    g_value_get_pointer (param_values + 1),
-	    g_value_get_pointer (param_values + 2),
+	    g_value_get_int (param_values + 2),
 	    g_value_get_int (param_values + 3),
-	    g_value_get_int (param_values + 4),
 	    data2);
 }
 
 static void
 gtk_html_embedded_class_init (GtkHTMLEmbeddedClass *class)
 {
-	GObjectClass *gobject_class;
-	GtkObjectClass *object_class;
+	GObjectClass *object_class;
 	GtkWidgetClass *widget_class;
 	GtkContainerClass *container_class;
 
-	gobject_class = G_OBJECT_CLASS (class);
-	object_class = GTK_OBJECT_CLASS (class);
+	object_class = G_OBJECT_CLASS (class);
 	widget_class = GTK_WIDGET_CLASS (class);
 	container_class = GTK_CONTAINER_CLASS (class);
 
@@ -199,7 +199,7 @@ gtk_html_embedded_class_init (GtkHTMLEmbeddedClass *class)
 			      G_TYPE_NONE, 1,
 			      G_TYPE_POINTER);
 
-	gobject_class->finalize = gtk_html_embedded_finalize;
+	object_class->finalize = gtk_html_embedded_finalize;
 
 	widget_class->size_request = gtk_html_embedded_size_request;
 	widget_class->size_allocate = gtk_html_embedded_size_allocate;
@@ -221,7 +221,7 @@ gtk_html_embedded_size_request (GtkWidget *widget, GtkRequisition *requisition)
 	child = gtk_bin_get_child (GTK_BIN (widget));
 
 	if (child) {
-		gtk_widget_size_request (child, requisition);
+		gtk_widget_get_preferred_size (child, requisition, NULL);
 	} else {
 		GtkRequisition self_requisition;
 
@@ -274,10 +274,10 @@ gtk_html_embedded_new (gchar *classid, gchar *name, gchar *type, gchar *data, gi
 
 	em->width = width;
 	em->height = height;
-	em->type = type ? g_strdup(type) : NULL;
-	em->classid = g_strdup(classid);
-	em->name = g_strdup(name);
-	em->data = g_strdup(data);
+	em->type = type ? g_strdup (type) : NULL;
+	em->classid = g_strdup (classid);
+	em->name = g_strdup (name);
+	em->data = g_strdup (data);
 
 	return (GtkWidget *)em;
 }
@@ -315,7 +315,7 @@ gtk_html_embedded_set_parameter (GtkHTMLEmbedded *ge, gchar *param, gchar *value
 		g_free (lookup);
 	g_hash_table_insert (ge->params,
 			     lookup ? param : g_strdup (param),
-			     value  ? g_strdup(value) : NULL);
+			     value  ? g_strdup (value) : NULL);
 }
 
 /**
